<?php
/**
 * @package HK_Exif_Tags
 * @version 1.1
 */
/*
Plugin Name: HK Exif Tags
Plugin URI: http://wordpress.org/extend/plugins/hk-exif-tags/
Description: Adds EXIF Tags below each image
Author: Henry Kellner
Version: 1.1
Author URI: http://hk.tt/
*/

add_filter('the_content', 'hk_filter_the_content');
add_filter('wp_read_image_metadata', 'hk_filter_add_exif','',3);

function hk_filter_add_exif($meta, $file, $sourceImageType) 
{
  if ( is_callable('exif_read_data') && 
       in_array($sourceImageType, apply_filters('wp_read_image_metadata_types', array(IMAGETYPE_JPEG, IMAGETYPE_TIFF_II, IMAGETYPE_TIFF_MM)) ) ) 
  {
    $exif = @exif_read_data( $file );

    if (!empty($exif['Make']))      $meta['make'] = $exif['Make'] ;
			
    return $meta;
  }
}

function hk_exif_tags_images_process($matches)
{
  if(!preg_match('/wp-image-([0-9]+)/', $matches[0], $idMatches) )
     return $matches[0];

  $id = $idMatches[1];

  $imgmeta = wp_get_attachment_metadata( $id );

  if($imgmeta['image_meta']['camera'] == '')
     return $matches[0];

  // Convert the shutter speed retrieve from database to fraction

  if ((1 / $imgmeta['image_meta']['shutter_speed']) > 1)
      {
         if ((number_format((1 / $imgmeta['image_meta']['shutter_speed']), 1)) == 1.3
         or number_format((1 / $imgmeta['image_meta']['shutter_speed']), 1) == 1.5
         or number_format((1 / $imgmeta['image_meta']['shutter_speed']), 1) == 1.6
         or number_format((1 / $imgmeta['image_meta']['shutter_speed']), 1) == 2.5){
            $pshutter = "1/" . number_format((1 / $imgmeta['image_meta']['shutter_speed']), 1, '.', '') . " sec";
         }
         else{
           $pshutter = "1/" . number_format((1 / $imgmeta['image_meta']['shutter_speed']), 0, '.', '') . " sec";
         }
      }
      else{
         $pshutter = $imgmeta['image_meta']['shutter_speed'] . " sec";
       }

  $result = $matches[0] . '<span style="color:#888; font-size:small; font-weight:normal;">';
  $result = $result . $imgmeta['image_meta']['make'] . ' ' . $imgmeta['image_meta']['camera'] . ' (' . $imgmeta['image_meta']['focal_length'] . 'mm, f/' . $imgmeta['image_meta']['aperture'] . ', ' . $pshutter . ', ISO' . $imgmeta['image_meta']['iso'] . ')';
  $result = $result . '<br></span>';

  return $result;
} 

function hk_filter_the_content($content) 
{
    return preg_replace_callback('/<img(?:.*?)<\/a>/', 'hk_exif_tags_images_process', $content);
} 

?>